@@ -4,27 +4,19 @@
 //! Stream records to client
 //!
 use std::fmt::Debug;
-use std::io::Error as IoError;
 use std::marker::PhantomData;
 
-use log::trace;
-use bytes::BytesMut;
-
-use dataplane::core::Version;
 use dataplane::core::Encoder;
 use dataplane::core::Decoder;
 use dataplane::api::Request;
 use dataplane::derive::Decode;
 use dataplane::derive::Encode;
-use dataplane::store::StoreValue;
-use dataplane::record::FileRecordSet;
-use dataplane::store::FileWrite;
 use dataplane::fetch::FetchablePartitionResponse;
 use dataplane::record::RecordSet;
 use dataplane::Isolation;
 
 pub type DefaultStreamFetchResponse = StreamFetchResponse<RecordSet>;
-pub type FileStreamFetchRequest = StreamFetchRequest<FileRecordSet>;
+
 pub type DefaultStreamFetchRequest = StreamFetchRequest<RecordSet>;
 
 use super::SpuServerApiKey;
@@ -68,18 +60,39 @@ where
     pub partition: FetchablePartitionResponse<R>,
 }
 
-impl FileWrite for StreamFetchResponse<FileRecordSet> {
-    fn file_encode(
-        &self,
-        src: &mut BytesMut,
-        data: &mut Vec<StoreValue>,
-        version: Version,
-    ) -> Result<(), IoError> {
-        trace!("file encoding FlvContinuousFetchResponse");
-        trace!("topic {}", self.topic);
-        self.topic.encode(src, version)?;
-        self.stream_id.encode(src, version)?;
-        self.partition.file_encode(src, data, version)?;
-        Ok(())
+#[cfg(feature = "file")]
+pub use file::*;
+
+#[cfg(feature = "file")]
+mod file {
+
+    use std::io::Error as IoError;
+
+    use log::trace;
+    use bytes::BytesMut;
+
+    use dataplane::core::Version;
+    use dataplane::store::StoreValue;
+    use dataplane::record::FileRecordSet;
+    use dataplane::store::FileWrite;
+
+    pub type FileStreamFetchRequest = StreamFetchRequest<FileRecordSet>;
+
+    use super::*;
+
+    impl FileWrite for StreamFetchResponse<FileRecordSet> {
+        fn file_encode(
+            &self,
+            src: &mut BytesMut,
+            data: &mut Vec<StoreValue>,
+            version: Version,
+        ) -> Result<(), IoError> {
+            trace!("file encoding FlvContinuousFetchResponse");
+            trace!("topic {}", self.topic);
+            self.topic.encode(src, version)?;
+            self.stream_id.encode(src, version)?;
+            self.partition.file_encode(src, data, version)?;
+            Ok(())
+        }
     }
 }
